--
-- DigsBagRename
-- Digren of Argent Dawn
-- 2010-09-05 3:20
--

local DebugMode = false;

---------------------------------------------------------------------------------
-- Localization
---------------------------------------------------------------------------------

LOCALIZATION = {
   USAGE = ("Usage: \"/dbr <number> <name>\".  <number> is 0 for the backpack, 1 to 4 for the character bags (right to left), and 5 to 11 for the bank bags (left to right).  <name> is the new bag name; leave blank to reset.");
};

---------------------------------------------------------------------------------
-- Bag Rename Function
---------------------------------------------------------------------------------

-- Grab a local copy of Blizzard's ContainerFrame_GenerateFrame function, before
-- replacing it.
BlizzardContainerFrame_GenerateFrame = ContainerFrame_GenerateFrame;

-- Replace Blizzard's _GenerateFrame function with one that can insert new bag
-- names.
ContainerFrame_GenerateFrame = function(
   frame,
   size,
   id)
   -- Execute Blizzard's original function to cover most of the bag rendering
   BlizzardContainerFrame_GenerateFrame(frame, size, id);

   local ContainerName = frame:GetName();
   if DebugMode then
      DEFAULT_CHAT_FRAME:AddMessage("Processing "..ContainerName);
   end
   local NewName = DigsBagRename_BagNames[id];
   if NewName ~= nil then
      _G[ContainerName.."Name"]:SetText(NewName);
   end
end

---------------------------------------------------------------------------------
-- Options Panel
---------------------------------------------------------------------------------

-- TBD once Blizzard enables their interface options panel for addons in the
-- Cataclysm beta.

---------------------------------------------------------------------------------
-- Slash Command Config
---------------------------------------------------------------------------------

SLASH_DIGSBAGRENAME1 = '/dbr';
SLASH_DIGSBAGRENAME2 = '/digsbagrename';

local function SlashHandler(msg, editbox)
   local BagSlot, BagName = msg:match("^(%d*)%s*(.-)$");

   if BagSlot ~= "" then
      BagSlot = tonumber(BagSlot);

      if BagSlot >= 0 and BagSlot <= 11 then
         if BagName ~= "" then
            DEFAULT_CHAT_FRAME:AddMessage("Slot "..BagSlot.." new bag name: "..BagName);
            DigsBagRename_BagNames[BagSlot] = BagName;
         else
            DEFAULT_CHAT_FRAME:AddMessage("Resetting slot "..BagSlot.." bag name");
            DigsBagRename_BagNames[BagSlot] = nil;
         end
      else
         DEFAULT_CHAT_FRAME:AddMessage(LOCALIZATION.USAGE);
      end
   else
      DEFAULT_CHAT_FRAME:AddMessage(LOCALIZATION.USAGE);
   end
end

SlashCmdList["DIGSBAGRENAME"] = SlashHandler;

---------------------------------------------------------------------------------
-- Start Up Event Hook
---------------------------------------------------------------------------------

-- Create frame to capture world events.
ptrDigsBagRenameFrame = CreateFrame(
   "Frame",
   "DigsBagRenameFrame",
   UIParent);

-- Register the world event to capture.  "PLAYER_ENTERING_WORLD" occurs
-- when a player enters the world, enters or leaves an instance, respawns
-- at a graveyard, or any other time the player sees a loading screen.
-- Other options: ADDON_LOADED fires after all the addon's saved variables
-- have been loaded.  PLAYER_LOGIN fires when entering world and reloading
-- UI, but not when entering/leaving instances.  PLAYER_ENTERING_WORLD seems to
-- work fine.
DigsBagRenameFrame:RegisterEvent("PLAYER_ENTERING_WORLD");

-- Function to execute on the registered world event.
function DigsBagRenameStartUp()
   if DebugMode then
      DEFAULT_CHAT_FRAME:AddMessage("DigsBagRenameStartUp");
   end
   -- If the saved variable doesn't already exist, define it as a table and call the
   -- basic slash handler to dump the default usage to the text window.
   if DigsBagRename_BagNames == nil then
      DigsBagRename_BagNames = {};
      SlashHandler("","");
   end
end

-- Attach function to the registered world event.
DigsBagRenameFrame:SetScript(
   "OnEvent",
   DigsBagRenameStartUp);